Welcome to test's documentation!
================================

.. jinja::

   .. include:: ../../../README.rst

after include

.. jinja:: first_ctx

    {% for k, v in topics.items() %}

    {{k}}
    ~~~~~
    {{v}}
    {% endfor %}

after first context

.. jinja:: second_ctx
   :file: tests/docs/basic/jinja_template.jinja
   :header_char: ~

after second context
